diff --git a/src/analysis/interpolation/qgsgridfilewriter.cpp b/src/analysis/interpolation/qgsgridfilewriter.cpp
index b7cffce..92b04fd 100644
--- a/src/analysis/interpolation/qgsgridfilewriter.cpp
+++ b/src/analysis/interpolation/qgsgridfilewriter.cpp
@@ -17,7 +17,9 @@
 
 #include "qgsgridfilewriter.h"
 #include "qgsinterpolator.h"
+#include "qgsvectorlayer.h"
 #include <QFile>
+#include <QFileInfo>
 #include <QProgressDialog>
 
 QgsGridFileWriter::QgsGridFileWriter( QgsInterpolator* i, QString outputPath, QgsRectangle extent, int nCols, int nRows , double cellSizeX, double cellSizeY )
@@ -96,6 +98,23 @@ int QgsGridFileWriter::writeFile( bool showProgressDialog )
     }
   }
 
+  // create prj file
+  QgsInterpolator::LayerData ld;
+  ld = mInterpolator->mLayerData.first();
+  QgsVectorLayer* vl = ld.vectorLayer;
+  QString crs = vl->crs().toWkt();
+  QFileInfo fi( mOutputFilePath );
+  QString fileName = fi.absolutePath() + "/" + fi.completeBaseName() + ".prj";
+  QFile prjFile( fileName );
+  if ( !prjFile.open( QFile::WriteOnly ) )
+  {
+    return 1;
+  }
+  QTextStream prjStream( &prjFile );
+  prjStream << crs;
+  prjStream << endl;
+  prjFile.close();
+
   delete progressDialog;
   return 0;
 }
diff --git a/src/analysis/interpolation/qgsinterpolator.h b/src/analysis/interpolation/qgsinterpolator.h
index 9712097..7a6e002 100644
--- a/src/analysis/interpolation/qgsinterpolator.h
+++ b/src/analysis/interpolation/qgsinterpolator.h
@@ -90,7 +90,7 @@ class ANALYSIS_EXPORT QgsInterpolator
      @return 0 in case of success*/
     int addVerticesToCache( QgsGeometry* geom, bool zCoord, double attributeValue );
 
-
+  friend class QgsGridFileWriter;
 };
 
 #endif
